@@ -247,7 +247,7 @@ static void fillFlightReservation(const QVector<QVariant> &reservations, const K
         desc.push_back(i18n("Boarding time: %1", QLocale().toString(boardingTime.time(), QLocale::ShortFormat)));
     }
     if (!departureGate.isEmpty()) {
-        desc.push_back(i18n("Departure gate: %1", departureGate));
+        desc.push_back(i18nc("flight departure gate", "Departure gate: %1", departureGate));
     }
 
     for (const auto &r : reservations) {
@@ -404,6 +404,8 @@ static void fillEvent(const KItinerary::Event &ev, const KCalendarCore::Event::P
             event->addAlarm(alarm);
         }
     }
+
+    event->setDescription(formatAddress(location.address()) + QLatin1Char('\n'));
 }
 
 static void fillEventReservation(const QVector<QVariant> &reservations, const KCalendarCore::Event::Ptr &event)
@@ -411,7 +413,7 @@ static void fillEventReservation(const QVector<QVariant> &reservations, const KC
     const auto ev = reservations.at(0).value<EventReservation>().reservationFor().value<KItinerary::Event>();
     fillEvent(ev, event);
 
-    QStringList desc;
+    QStringList desc = { event->description() };
     for (const auto &r : reservations) {
         const auto reservation = r.value<EventReservation>();
         const auto person = reservation.underName().value<KItinerary::Person>();
@@ -459,10 +461,10 @@ static void fillFoodReservation(const FoodEstablishmentReservation &reservation,
 
     QStringList desc;
     if (reservation.partySize() > 0) {
-        desc.push_back(i18n("Number Of People: %1", reservation.partySize()));
+        desc.push_back(i18n("Number of people: %1", reservation.partySize()));
     }
     if (!reservation.reservationNumber().isEmpty()) {
-        desc.push_back(i18n("Reservation reference: %1", reservation.reservationNumber()));
+        desc.push_back(i18n("Booking reference: %1", reservation.reservationNumber()));
     }
     const auto person = reservation.underName().value<KItinerary::Person>();
     if (!person.name().isEmpty()) {
@@ -476,28 +478,32 @@ static void fillRentalCarReservation(const RentalCarReservation &reservation, co
     const auto rentalCalPickup = reservation.pickupLocation();
     const auto addressPickUp = rentalCalPickup.address();
     const auto rentalCar = reservation.reservationFor().value<RentalCar>();
-    event->setSummary(i18n("Rental Car reservation: %1", rentalCar.name()));
-    event->setLocation(formatAddressSingleLine(addressPickUp));
+    event->setSummary(i18n("Rental car reservation: %1", rentalCar.name()));
+    event->setLocation(rentalCalPickup.name());
     fillGeoPosition(rentalCalPickup, event);
 
     event->setDtStart(reservation.pickupTime());
     event->setDtEnd(reservation.dropoffTime());
     event->setAllDay(false);
     event->setTransparency(KCalendarCore::Event::Transparent);
-    event->setSummary(i18n("Rent car reservation: %1", rentalCar.name()));
 
-    const QString pickUpAddress = formatAddress(addressPickUp);
-    const auto rentalCalDropOff = reservation.dropoffLocation();
-    const auto addressDropOff = rentalCalDropOff.address();
-    const QString dropAddress = formatAddress(addressDropOff);
+    QStringList desc;
+    if (!addressPickUp.isEmpty()) {
+        desc.push_back(i18n("Pickup location: %1\n%2\n", rentalCalPickup.name(), formatAddress(addressPickUp)));
+    }
+    const auto dropOff = reservation.dropoffLocation();
+    if (!dropOff.name().isEmpty()) {
+        desc.push_back(i18n("Dropoff location: %1\n%2\n", dropOff.name(), formatAddress(dropOff.address())));
+    }
+    if (!reservation.reservationNumber().isEmpty()) {
+        desc.push_back(i18n("Booking reference: %1", reservation.reservationNumber()));
+    }
+    const auto person = reservation.underName().value<KItinerary::Person>();
+    if (!person.name().isEmpty()) {
+        desc.push_back(i18n("Under name: %1", person.name()));
+    }
 
-    const QString description = i18n("Reservation reference: %1\nUnder name: %2\n\nPickUp location: %3\n\nDropoff Location: %4",
-                                     reservation.reservationNumber(),
-                                     reservation.underName().value<KItinerary::Person>().name(),
-                                     pickUpAddress,
-                                     dropAddress);
-
-    event->setDescription(description);
+    event->setDescription(desc.join(QLatin1Char('\n')));
 }
 
 static void fillTaxiReservation(const TaxiReservation &reservation, const KCalendarCore::Event::Ptr &event)
@@ -516,7 +522,7 @@ static void fillTaxiReservation(const TaxiReservation &reservation, const KCalen
     //TODO event->setSummary(i18n("Rent car reservation: %1", rentalCar.name()));
     const QString pickUpAddress = formatAddress(addressPickUp);
 
-    const QString description = i18n("Reservation reference: %1\nUnder name: %2\nPickUp location: %3",
+    const QString description = i18n("Reservation reference: %1\nUnder name: %2\nPickup location: %3",
                                      reservation.reservationNumber(),
                                      reservation.underName().value<KItinerary::Person>().name(),
                                      pickUpAddress);
